@@ -1,7 +1,7 @@
 //! Small demo which creates 3 maps, translated, scaled, and rotated, and writes them out if the
 //! debug_maps feature is enabled
 
-use cell_map::{CellMap, CellMapParams, Layer};
+use cell_map::{Bounds, CellMap, CellMapParams, Layer};
 use nalgebra::Vector2;
 use serde::Serialize;
 
@@ -14,14 +14,14 @@ enum Layers {
 
 fn main() {
     let translated = CellMap::<Layers, f64>::new(CellMapParams {
-        num_cells: Vector2::new(10, 10),
         cell_size: Vector2::new(1.0, 1.0),
+        cell_bounds: Bounds::new((0, 10), (0, 10)).unwrap(),
         position_in_parent: Vector2::new(5.0, 5.0),
         ..Default::default()
     });
 
     let rotated = CellMap::<Layers, f64>::new(CellMapParams {
-        num_cells: Vector2::new(10, 10),
+        cell_bounds: Bounds::new((0, 10), (0, 10)).unwrap(),
         cell_size: Vector2::new(1.0, 1.0),
         position_in_parent: Vector2::new(5.0, 5.0),
         rotation_in_parent_rad: std::f64::consts::FRAC_PI_4,
@@ -29,7 +29,7 @@ fn main() {
     });
 
     let scaled = CellMap::<Layers, f64>::new(CellMapParams {
-        num_cells: Vector2::new(10, 10),
+        cell_bounds: Bounds::new((0, 10), (0, 10)).unwrap(),
         cell_size: Vector2::new(0.5, 0.5),
         position_in_parent: Vector2::new(5.0, 5.0),
         rotation_in_parent_rad: std::f64::consts::FRAC_PI_4,
