@@ -11,7 +11,9 @@ use nalgebra::{Point2, Vector2};
 use ndarray::{s, Array2, ArrayView2, ArrayViewMut2};
 use serde::Serialize;
 
-use crate::{extensions::Point2Ext, map_metadata::CellMapMetadata, CellMap, Error, Layer};
+use crate::{
+    cell_map::Bounds, extensions::Point2Ext, map_metadata::CellMapMetadata, CellMap, Error, Layer,
+};
 
 // ------------------------------------------------------------------------------------------------
 // TRAITS
@@ -60,6 +62,7 @@ where
     fn reset(&mut self, layer: Option<L>);
 }
 
+/// Rectangular bounds in an XY plane. Lower bound is inclusive, upper exclusive.
 pub(crate) type RectBounds = Vector2<(usize, usize)>;
 
 /// A [`Slicer`] which produces cells in `(x, y)` order inside a layer, with `x` increasing most
@@ -88,7 +91,7 @@ pub struct Windows {
 #[derive(Debug, Clone)]
 #[allow(missing_copy_implementations)]
 pub struct Line {
-    bounds: RectBounds,
+    bounds: Bounds,
     map_meta: CellMapMetadata,
 
     start_parent: Point2<f64>,
@@ -226,9 +229,9 @@ where
     fn slice_mut(&self, data: &'a mut Array2<T>) -> Option<Self::OutputMut> {
         if self.index.in_bounds(&self.bounds) {
             let x0 = self.index.x - self.semi_width.x;
-            let x1 = self.index.x + self.semi_width.x;
+            let x1 = self.index.x + self.semi_width.x + 1;
             let y0 = self.index.y - self.semi_width.y;
-            let y1 = self.index.y + self.semi_width.y;
+            let y1 = self.index.y + self.semi_width.y + 1;
             Some(data.slice_mut(s![y0..y1, x0..x1]))
         } else {
             None
@@ -270,8 +273,8 @@ impl Line {
         let end_map = map_meta.to_parent.inverse_transform_point(&end_parent);
 
         // Get map edges in floating point for bounds check
-        let map_x_lim = map_meta.num_cells.x as f64;
-        let map_y_lim = map_meta.num_cells.y as f64;
+        let map_x_lim = (map_meta.num_cells.x) as f64;
+        let map_y_lim = (map_meta.num_cells.y) as f64;
 
         // Check start and end points are inside the map
         if start_map.x < 0.0
@@ -301,7 +304,7 @@ impl Line {
             .ok_or_else(|| Error::PositionOutsideMap("Line::End".into(), end_parent))?;
 
         Ok(Self {
-            bounds: map_meta.get_bounds(),
+            bounds: map_meta.cell_bounds,
             map_meta,
             start_parent,
             end_parent,
@@ -344,14 +347,14 @@ where
         // Get the index
         let index = self.get_current_index()?;
 
-        Some(&data[index.as_array2_index()])
+        data.get(index.as_array2_index())
     }
 
     fn slice_mut(&self, data: &'a mut Array2<T>) -> Option<Self::OutputMut> {
         // Get the index
         let index = self.get_current_index()?;
 
-        Some(&mut data[index.as_array2_index()])
+        data.get_mut(index.as_array2_index())
     }
 
     fn advance(&mut self) {
@@ -361,11 +364,10 @@ where
             None => return,
         };
 
-        // If the current index matches the end cell, we are at the end, and set current to None
-        if curr_index == self.end_index {
-            self.current_map = None;
-            return;
-        }
+        // Calculate the param value, i.e. how far along the line we are. This will be used to
+        // check if we are beyond the end of the line
+        let param = (self.current_map.unwrap() - self.start_map).norm()
+            / (self.end_map - self.start_map).norm();
 
         // Calculate the changes in the line parameter needed to reach the next x and y grid line
         // respectively. Also add on the cell boundary precision to ensure that we will actually
@@ -378,8 +380,15 @@ where
         // Whichever component of delta is smaller is what we need to advance along the line by.
         let delta = delta_param.x.min(delta_param.y);
 
-        // Move current to current + dir*delta
-        self.current_map = Some(self.current_map.unwrap() + (self.dir * delta));
+        // If any of param + delta is > 1, the next point would be beyond the end of the line, so
+        // we should end here
+        if delta + param > 1.0 {
+            self.current_map = None;
+        }
+        // Otherwise, move current to current + dir*delta
+        else {
+            self.current_map = Some(self.current_map.unwrap() + (self.dir * delta));
+        }
 
         // Write new step report to file
         #[cfg(feature = "debug_iters")]
