@@ -5,7 +5,7 @@
 // ------------------------------------------------------------------------------------------------
 
 use super::*;
-use crate::{test_utils::TestLayers, CellMapParams};
+use crate::{cell_map::Bounds, test_utils::TestLayers, CellMapParams};
 
 /// Check that iterator constructors return the right ok or error.
 #[test]
@@ -14,7 +14,7 @@ fn construction() {
     let mut map = CellMap::<TestLayers, f64>::new_from_elem(
         CellMapParams {
             cell_size: Vector2::new(1.0, 1.0),
-            num_cells: Vector2::new(5, 5),
+            cell_bounds: Bounds::new((0, 5), (0, 5)).unwrap(),
             ..Default::default()
         },
         1.0,
@@ -37,7 +37,7 @@ fn counts() -> Result<(), Error> {
     let mut map = CellMap::<TestLayers, f64>::new_from_elem(
         CellMapParams {
             cell_size: Vector2::new(1.0, 1.0),
-            num_cells: Vector2::new(5, 5),
+            cell_bounds: Bounds::new((0, 5), (0, 5)).unwrap(),
             ..Default::default()
         },
         1.0,
@@ -69,13 +69,66 @@ fn counts() -> Result<(), Error> {
     Ok(())
 }
 
+#[test]
+fn window() -> Result<(), Error> {
+    // Dummy map
+    let map = CellMap::<TestLayers, f64>::new_from_elem(
+        CellMapParams {
+            cell_size: Vector2::new(1.0, 1.0),
+            cell_bounds: Bounds::new((0, 5), (0, 6)).unwrap(),
+            ..Default::default()
+        },
+        1.0,
+    );
+
+    // Check shape is correct
+    let first = map
+        .window_iter(Vector2::new(1, 1))?
+        .layer(TestLayers::Layer0)
+        .next();
+
+    assert_eq!(first.unwrap().shape(), &[3, 3]);
+
+    // Check the order of cells produced is correct
+    let indices: Vec<(usize, usize)> = map
+        .window_iter(Vector2::new(1, 1))?
+        .layer(TestLayers::Layer0)
+        .indexed()
+        .map(|((_, idx), _)| (idx.x, idx.y))
+        .collect();
+
+    assert_eq!(
+        indices,
+        vec![
+            (1, 1),
+            (2, 1),
+            (3, 1),
+            // (4, 1),
+            (1, 2),
+            (2, 2),
+            (3, 2),
+            // (4, 2),
+            (1, 3),
+            (2, 3),
+            (3, 3),
+            // (4, 3),
+            (1, 4),
+            (2, 4),
+            (3, 4),
+            // (4, 4),
+        ]
+    );
+
+    Ok(())
+}
+
 #[test]
 fn line() -> Result<(), Error> {
     // Dummy map
     let map = CellMap::<TestLayers, f64>::new_from_elem(
         CellMapParams {
             cell_size: Vector2::new(1.0, 1.0),
-            num_cells: Vector2::new(5, 5),
+            cell_bounds: Bounds::new((0, 6), (0, 6)).unwrap(),
             ..Default::default()
         },
         1.0,
